==> vue-drop-times-2.8.0.tgz: package/lib/pc.js <==
import { renderless, api } from "@dft-vue-2-opentiny/vue-renderless/drop-times/vue";
import { defineComponent, props, setup as _setup } from "@dft-vue-2-opentiny/vue-common";
import Select from "@dft-vue-2-opentiny/vue-select";
import Option from "@dft-vue-2-opentiny/vue-option";
function normalizeComponent(scriptExports, render, staticRenderFns, functionalTemplate, injectStyles, scopeId, moduleIdentifier, shadowMode) {
  var options = typeof scriptExports === "function" ? scriptExports.options : scriptExports;
  if (render) {
    options.render = render;
    options.staticRenderFns = staticRenderFns;
    options._compiled = true;
  }
  if (functionalTemplate) {
    options.functional = true;
  }
  if (scopeId) {
    options._scopeId = "data-v-" + scopeId;
  }
  var hook;
  if (moduleIdentifier) {
    hook = function hook2(context) {
      context = context || // cached call
      this.$vnode && this.$vnode.ssrContext || // stateful
      this.parent && this.parent.$vnode && this.parent.$vnode.ssrContext;
      if (!context && typeof __VUE_SSR_CONTEXT__ !== "undefined") {
        context = __VUE_SSR_CONTEXT__;
      }
      if (injectStyles) {
        injectStyles.call(this, context);
      }
      if (context && context._registeredComponents) {
        context._registeredComponents.add(moduleIdentifier);
      }
    };
    options._ssrRegister = hook;
  } else if (injectStyles) {
    hook = shadowMode ? function() {
      injectStyles.call(this, (options.functional ? this.parent : this).$root.$options.shadowRoot);
    } : injectStyles;
  }
  if (hook) {
    if (options.functional) {
      options._injectStyles = hook;
      var originalRender = options.render;
      options.render = function renderWithStyleInjection(h, context) {
        hook.call(context);
        return originalRender(h, context);
      };
    } else {
      var existing = options.beforeCreate;
      options.beforeCreate = existing ? [].concat(existing, hook) : [hook];
    }
  }
  return {
    exports: scriptExports,
    options
  };
}

var __vue2_script = defineComponent({
  components: {
    TinySelect: Select,
    TinyOption: Option
  },
  props: [].concat(props, ["size", "tabindex", "modelValue", "placeholder", "start", "end", "step", "popperClass", "popperAppendToBody"]),
  emits: ["change", "update:modelValue", "clear", "visible-change"],
  setup: function setup(props2, context) {
    return _setup({
      props: props2,
      context,
      renderless,
      api
    });
  }
});
var render = function render2() {
  var _vm = this;
  var _h = _vm.$createElement;
  var _c = _vm._self._c || _h;
  return _c("tiny-select", _vm._b({
    attrs: {
      "tabindex": _vm.tabindex,
      "size": _vm.size,
      "placeholder": _vm.placeholder,
      "popper-class": "tiny-drop-times" + (_vm.popperClass ? " " + _vm.popperClass : ""),
      "popper-append-to-body": _vm.popperAppendToBody
    },
    on: {
      "change": _vm.change,
      "clear": function clear($event) {
        return _vm.$emit("clear");
      },
      "visible-change": function visibleChange($event) {
        return _vm.$emit("visible-change", $event);
      }
    },
    model: {
      value: _vm.state.selectedValue,
      callback: function callback($$v) {
        _vm.$set(_vm.state, "selectedValue", $$v);
      },
      expression: "state.selectedValue"
    }
  }, "tiny-select", _vm.a(_vm.$attrs, ["^on[A-Z]"]), false), _vm._l(_vm.state.options, function(item, index) {
    return _c("tiny-option", {
      key: index,
      attrs: {
        "label": item.label,
        "value": item.value
      }
    });
  }), 1);
};
var staticRenderFns = [];
var __cssModules = {};
var __component__ = /* @__PURE__ */ normalizeComponent(__vue2_script, render, staticRenderFns, false, __vue2_injectStyles, null, null, null);
function __vue2_injectStyles(context) {
  for (var o in __cssModules) {
    this[o] = __cssModules[o];
  }
}
var pc = /* @__PURE__ */ function() {
  return __component__.exports;
}();
export {
  pc as default
};

==> vue-drop-times-2.24.0.tgz: package/lib/pc.js <==
import { renderless, api } from '@opentinyvue/vue-renderless/drop-times/vue';
import { defineComponent, props, setup } from '@opentinyvue/vue-common';
import Select from '@opentinyvue/vue-select';
import Option from '@opentinyvue/vue-option';

function normalizeComponent(scriptExports, render, staticRenderFns, functionalTemplate, injectStyles, scopeId, moduleIdentifier, shadowMode) {
  var options = typeof scriptExports === "function" ? scriptExports.options : scriptExports;
  if (render) {
    options.render = render;
    options.staticRenderFns = staticRenderFns;
    options._compiled = true;
  }
  var hook;
  if (injectStyles) {
    hook = injectStyles;
  }
  if (hook) {
    if (options.functional) {
      options._injectStyles = hook;
      var originalRender = options.render;
      options.render = function renderWithStyleInjection(h, context) {
        hook.call(context);
        return originalRender(h, context);
      };
    } else {
      var existing = options.beforeCreate;
      options.beforeCreate = existing ? [].concat(existing, hook) : [hook];
    }
  }
  return {
    exports: scriptExports,
    options
  };
}

var __vue2_script = defineComponent({
  components: {
    TinySelect: Select,
    TinyOption: Option
  },
  props: [].concat(props, ["size", "tabindex", "modelValue", "placeholder", "start", "end", "step", "popperClass", "popperAppendToBody"]),
  emits: ["change", "update:modelValue", "clear", "visible-change"],
  setup: function setup$1(props2, context) {
    return setup({
      props: props2,
      context,
      renderless,
      api
    });
  }
});
var render = function render2() {
  var _vm = this;
  var _h = _vm.$createElement;
  var _c = _vm._self._c || _h;
  return _c("tiny-select", _vm._b({
    attrs: {
      "tabindex": _vm.tabindex,
      "size": _vm.size,
      "placeholder": _vm.placeholder,
      "popper-class": "tiny-drop-times" + (_vm.popperClass ? " " + _vm.popperClass : ""),
      "popper-append-to-body": _vm.popperAppendToBody
    },
    on: {
      "change": _vm.change,
      "clear": function clear($event) {
        return _vm.$emit("clear");
      },
      "visible-change": function visibleChange($event) {
        return _vm.$emit("visible-change", $event);
      }
    },
    model: {
      value: _vm.state.selectedValue,
      callback: function callback($$v) {
        _vm.$set(_vm.state, "selectedValue", $$v);
      },
      expression: "state.selectedValue"
    }
  }, "tiny-select", _vm.a(_vm.$attrs, ["^on[A-Z]"]), false), _vm._l(_vm.state.options, function(item, index) {
    return _c("tiny-option", {
      key: index,
      attrs: {
        "label": item.label,
        "value": item.value
      }
    });
  }), 1);
};
var staticRenderFns = [];
var __cssModules = {};
var __component__ = /* @__PURE__ */ normalizeComponent(__vue2_script, render, staticRenderFns, false, __vue2_injectStyles);
function __vue2_injectStyles(context) {
  for (var o in __cssModules) {
    this[o] = __cssModules[o];
  }
}
var pc = /* @__PURE__ */ function() {
  return __component__.exports;
}();

export { pc as default };
